@@ -34,7 +34,13 @@ def del_dbg(control):
         control.clear()
 
 
-update_control(source_package_cb=bump_debhelper, binary_package_cb=del_dbg)
+update_control(binary_package_cb=del_dbg)
+if not dbg_packages:
+    # no debug packages found to remove
+    sys.exit(0)
+
+update_control(source_package_cb=bump_debhelper)
+
 
 current_version = os.environ["CURRENT_VERSION"]
 migrate_version = "<< %s%s" % (
@@ -43,7 +49,7 @@ migrate_version = "<< %s%s" % (
 
 
 def migrate_dh_strip(line, target):
-    if line.startswith(b'dh_strip '):
+    if line.startswith(b'dh_strip ') or line.startswith(b'dh '):
         for dbg_pkg in dbg_packages:
             if ('--dbg-package=%s' % dbg_pkg).encode('utf-8') in line:
                 line = line.replace(
@@ -54,21 +60,14 @@ def migrate_dh_strip(line, target):
     return line
 
 
-if check_cdbs():
-    # Ah, cdbs.
-    raise Exception("package uses cdbs")
-
 update_rules(migrate_dh_strip)
 
-
-if not dbg_packages:
-    # no debug packages found to remove
-    sys.exit(2)
-
-
 difference = dbg_packages.symmetric_difference(dbg_migration_done)
 
 if difference:
+    if check_cdbs():
+        # Ah, cdbs.
+        raise Exception("package uses cdbs")
     raise Exception("packages missing %r" % difference)
 
 print("Transition to automatic debug package%s (from: %s)." %
