@@ -196,6 +196,8 @@ def known_bad_guess(datum):
             return True
         if parsed_url.hostname == 'bugs.freedesktop.org':
             return True
+    if datum.value.lower() == 'unknown':
+        return True
     return False
 
 
@@ -466,9 +468,14 @@ def guess_from_readme(path, trust_package):
                         url = args[0]
                     if plausible_vcs_url(url):
                         urls.append(sanitize_vcs_url(url))
-                m = re.match(
-                    b'.*\\(https://travis-ci.org/([^/]+)/([^/]+)\\)', line)
-                if m:
+                for m in re.finditer(
+                        b'https://travis-ci.org/([^/]+)/([^/?.]+)', line):
+                    yield UpstreamDatum(
+                        'Repository', 'https://github.com/%s/%s' % (
+                            m.group(1).decode(), m.group(2).decode()),
+                        'possible')
+                for m in re.finditer(
+                        b'https://coveralls.io/r/([^/]+)/([^/?.]+)', line):
                     yield UpstreamDatum(
                         'Repository', 'https://github.com/%s/%s' % (
                             m.group(1).decode(), m.group(2).decode()),
@@ -490,6 +497,17 @@ def guess_from_readme(path, trust_package):
         yield UpstreamDatum('Repository', urls[0], 'possible')
 
 
+def guess_from_debian_patch(path, trust_package):
+    with open(path, 'r') as f:
+        for line in f:
+            if line.startswith('Forwarded: '):
+                forwarded = line.split(':', 1)[1].strip()
+                bug_db = bug_database_from_issue_url(forwarded)
+                if bug_db:
+                    yield UpstreamDatum('Bug-Database', bug_db, 'possible')
+    return []
+
+
 def guess_from_meta_json(path, trust_package):
     import json
     with open(path, 'r') as f:
@@ -730,6 +748,17 @@ def _get_guessers(path, trust_package=False):
         os.path.splitext(n)[1] not in ('.html', '.pdf', '.xml')]
     CANDIDATES.extend([(n, guess_from_readme) for n in readme_filenames])
 
+    try:
+        debian_patches = [
+            os.path.join('debian', 'patches', n)
+            for n in os.listdir('debian/patches')
+            if os.path.isfile(os.path.join('debian/patches', n))]
+    except FileNotFoundError:
+        pass
+    else:
+        CANDIDATES.extend(
+            [(p, guess_from_debian_patch) for p in debian_patches])
+
     yield guess_from_environment()
 
     for relpath, guesser in CANDIDATES:
@@ -806,6 +835,9 @@ def guess_from_sf(sf_project):
         yield 'Name', data['name']
     if 'external_homepage' in data:
         yield 'Homepage', data['external_homepage']
+    if 'preferred_support_url' in data:
+        if verify_bug_database_url(data['preferred_support_url']):
+            yield 'Bug-Database', data['preferred_support_url']
     # In theory there are screenshots linked from the sourceforge project that
     # we can use, but if there are multiple "subprojects" then it will be
     # unclear which one they belong to.
@@ -841,7 +873,7 @@ def extend_from_external_guesser(
 
 def extend_from_sf(upstream_metadata, sf_project):
     # The set of fields that sf can possibly provide:
-    sf_fields = ['Homepage', 'Name']
+    sf_fields = ['Homepage', 'Name', 'Repository']
     sf_certainty = upstream_metadata['Archive'].certainty
 
     return extend_from_external_guesser(
@@ -884,6 +916,16 @@ def extract_sf_project_name(url):
         return m.group(1)
 
 
+def bug_database_from_issue_url(url):
+    parsed_url = urlparse(url)
+    if parsed_url.netloc == 'github.com':
+        path_elements = parsed_url.path.strip('/').split('/')
+        if len(path_elements) > 2 and path_elements[2] == 'issues':
+            return urlunparse(
+                ('https', 'github.com', '/'.join(path_elements[:3]),
+                 None, None, None))
+
+
 def guess_bug_database_url_from_repo_url(url):
     parsed_url = urlparse(url)
     if parsed_url.netloc == 'github.com':
@@ -938,7 +980,12 @@ def verify_bug_database_url(url):
             return False
         api_url = 'https://api.github.com/repos/%s/%s' % (
             path_elements[0], path_elements[1])
-        data = _load_json_url(api_url)
+        try:
+            data = _load_json_url(api_url)
+        except urllib.error.HTTPError as e:
+            if e.status == 404:
+                return False
+            raise
         return data['has_issues']
     if is_gitlab_site(parsed_url.netloc):
         path_elements = parsed_url.path.strip('/').split('/')
@@ -950,7 +997,7 @@ def verify_bug_database_url(url):
             data = _load_json_url(api_url)
         except urllib.error.HTTPError as e:
             if e.status == 404:
-                return
+                return False
             raise
         return len(data) > 0
     return None
@@ -1061,7 +1108,7 @@ def extend_upstream_metadata(upstream_metadata, path, minimum_certainty=None,
             upstream_metadata['Archive'] = UpstreamDatum(
                 'Archive', 'SourceForge', 'likely')
             upstream_metadata['X-SourceForge-Project'] = UpstreamDatum(
-                'X-SourceForge-Project', 'project', 'likely')
+                'X-SourceForge-Project', project, 'likely')
 
     archive = upstream_metadata.get('Archive')
     if (archive and archive.value == 'SourceForge' and
